/*
  GetCharState.ino

  This sketch demonstrates how GetCharState function works.

  This sketch shows the state of your keypad on your LCD screen.

  This sketch requires a 16X2 caracter LCD module with a Hitachi HD44780 
driver (or compatible).  Pin assignments are assumed as follows:

* LCD RS pin is connected to Arduino D12 pin.
* LCD Enable pin is connected to Arduino D11 pin.
* LCD D4 pin is connected to Arduino D5 pin.
* LCD D5 pin is connected to Arduino D4 pin.
* LCD D6 pin is connected to Arduino D3 pin.
* LCD D7 pin is connected to Arduino D2 pin.
* LCD R/W pin is connected to GND.

  This sketch also requires a resistive voltage divider keypad.
This sketch assumes that you use the 4X4 keypad introduced in the
following web page:

  http://www3.big.or.jp/~schaft/hardware/product/keypad4X4/page001.html

  This example code is in the public domain.
*/

// include library codes
#include <LiquidCrystal.h> // library for LCD
#include <ResKeypad.h> // library for keypad

// variables
LiquidCrystal lcd(12, 11, 5, 4, 3, 2); // define pin assignments of LCD module
ResKeypad keypad(A4,16,RESKEYPAD_4X4,RESKEYPAD_4X4_SIDE_A); // enable this line if SIDE A of keypad is used
//ResKeypad keypad(A4,16,RESKEYPAD_4X4,RESKEYPAD_4X4_SIDE_B); // enable this line if SIDE B of keypad is used

// functions
void setup()
{
  // initialize LCD
  lcd.begin(16,2);
} // setup

void loop()
{
  static int LastChar=1000; // character code obtained by last GetCharState() call
  char CurrentChar;

  CurrentChar=keypad.GetCharState();
  if(CurrentChar!=LastChar) {
    lcd.setCursor(0,0);
    lcd.clear();
    if(CurrentChar=='\0') {
      lcd.print("No key.");
    } else {
      lcd.print(CurrentChar);
      lcd.print(" is pressed.");
    } // if
    LastChar=CurrentChar;
  } // if
} // loop
