/*
  WaitForKey.ino

  This sketch demonstrats how WaitForKey function works.

  This sketch shows the key you pressed on your LCD screen.

  This sketch requires a 16X2 caracter LCD module with a Hitachi HD44780 
driver (or compatible).  Pin assignments are assumed as follows:

* LCD RS pin is connected to Arduino D12 pin.
* LCD Enable pin is connected to Arduino D11 pin.
* LCD D4 pin is connected to Arduino D5 pin.
* LCD D5 pin is connected to Arduino D4 pin.
* LCD D6 pin is connected to Arduino D3 pin.
* LCD D7 pin is connected to Arduino D2 pin.
* LCD R/W pin is connected to GND.

  This sketch also requires a resistive voltage divider keypad.
This sketch assumes that you use the 4X4 keypad introduced in the
following web page:

  http://www3.big.or.jp/~schaft/hardware/product/keypad4X4/page001.html

  This example code is in the public domain.
*/

// include library codes
#include <LiquidCrystal.h> // library for LCD
#include <ResKeypad.h> // library for keypad

// variables
LiquidCrystal lcd(12, 11, 5, 4, 3, 2); // define pin assignments of LCD module
ResKeypad keypad(A4,16,RESKEYPAD_4X4); // define keypad

// functions
void setup()
{
  // initialize LCD
  lcd.begin(16,2);
  lcd.setCursor(0,0);
  lcd.print("Press keys.");
} // setup

void loop()
{
  signed char key;

  key=keypad.WaitForKey(); // wait until a key is pressed and get a key number
  lcd.setCursor(0,1);
  lcd.print("SW");
  lcd.print(key+1);
  lcd.print("    ");
} // loop
